tuple/rem.hpp

The tuple/rem.hpp header defines a macro that removes the parentheses from a tuple.

#### Usage

#include <boost/preprocessor/tuple/rem.hpp>

#### Contents

- BOOST_PP_TUPLE_REM (v)
- BOOST_PP_TUPLE_REM_CTOR (v)

© Copyright Housemarque Oy 2002
© Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)